@@ -1,4 +1,3 @@
-import os
 import io
 import glob
 import shutil
@@ -6,6 +5,7 @@ import functools
 import hashlib
 import inspect
 import pathlib
+import warnings
 from collections import defaultdict
 from typing import Callable, List, Union, Any
 
@@ -36,12 +36,12 @@ class WebvizStorage:
         self.storage_functions.add(func)
 
     @property
-    def storage_folder(self) -> str:
+    def storage_folder(self) -> pathlib.Path:
         return self._storage_folder
 
     @storage_folder.setter
-    def storage_folder(self, path: str) -> None:
-        os.makedirs(path, exist_ok=True)
+    def storage_folder(self, path: pathlib.Path) -> None:
+        path.mkdir(parents=True, exist_ok=True)
         self._storage_folder = path
 
     @property
@@ -73,6 +73,24 @@ class WebvizStorage:
                         repr(argtuples)
                     ] = argtuples
 
+                for (argname, argvalue) in argtuples:
+                    # Check that values of decorated functions are not pandas objects.
+                    # This function could probably at some point be moved into a pytest
+                    # fixture (given that plugins use type hints) in order to slightly
+                    # reduce running time.
+                    if isinstance(argvalue, (pd.DataFrame, pd.Series)):
+                        warnings.warn(
+                            f"{func.__module__}.{func.__name__} is a @webvizstore decorated "
+                            f"function, and argument {argname} has been given a pandas "
+                            "object as value. Since pandas.DataFrames and pandas.Series are "
+                            "known to not have unique/deterministic __repr__ functions, "
+                            "they do not work well with @webvizstore (or flask-caching). "
+                            "Consider moving to another object with a deterministic "
+                            "__repr__ representation more suitable for hashing.",
+                            RuntimeWarning,
+                            stacklevel=0,
+                        )
+
     def _unique_path(self, func: Callable, argtuples: tuple) -> str:
         """Encodes the argumenttuples as bytes, and then does a sha256 on that.
         Mutable arguments are accepted in the argument tuples, however it is
@@ -85,7 +103,7 @@ class WebvizStorage:
 
         filename = f"{func.__module__}-{func.__name__}-{hashed_args}"
 
-        return os.path.join(self.storage_folder, filename)
+        return str(self.storage_folder / filename)
 
     @staticmethod
     def _undecorate(func: Callable) -> Callable:
